using FitConnect.Models;
using Microsoft.AspNetCore.Http;

namespace FitConnect.Interfaces;

public interface IFitConnectClient {
    /// <summary>
    ///     Receives the SecurityEventTokens for a given case
    /// </summary>
    /// <param name="caseId">ID of the case</param>
    /// <param name="destinationId">Skips signature validation if null!</param>
    /// <param name="skipTest">Specifies if the SET signature test is skipped</param>
    /// <returns>List of the <see cref="SecurityEventToken" /></returns>
    public Task<List<SecurityEventToken>> GetEventLogAsync(Guid caseId,
        Guid destinationId,
        bool skipTest = false);

    public bool ValidateCallback(string callbackSecret, HttpRequest request) =>
        FitConnectClient.ValidateCallback(callbackSecret, request);

    public bool ValidateCallback(string hmac, string callbackSecret, long timestamp, string httpBody) =>
        FitConnectClient.ValidateCallback(hmac, callbackSecret, timestamp, httpBody);
}
